/*                  - Mellanox Confidential and Proprietary -
 *
 *  Copyright (C) 2010-2011, Mellanox Technologies Ltd.  ALL RIGHTS RESERVED.
 *
 *  Except as specifically permitted herein, no portion of the information,
 *  including but not limited to object code and source code, may be reproduced,
 *  modified, distributed, republished or otherwise exploited in any form or by
 *  any means for any purpose without the prior written permission of Mellanox
 *  Technologies Ltd. Use of software subject to the terms and conditions
 *  detailed in the file "COPYING".
 *
 */

#include "cc_mgr.h"
#include "cc_mgr_api.h"


//============================================================================//
/* globals */
static CongestionControlManager* ccMgr        = NULL;


//============================================================================//
int initCCMgr(osm_opensm_t *p_osm,
        char *osm_plugin_options)
{
    try {
        if (ccMgr)
            delete ccMgr;
        ccMgr = new CongestionControlManager(p_osm, osm_plugin_options);
        OSM_LOG(&p_osm->log, OSM_LOG_VERBOSE,
                "CC_MGR - Created Congestion Control Manager.\n");
        return 0;
    } catch (exception &e) {
        CongestionControlManager::printException(e, &p_osm->log);
        return 1;
    }
}


//============================================================================//
int runCCMgr(osm_opensm_t *p_osm,
        osm_epi_event_id_t osm_event_id)
{
    try {
        if (!ccMgr)
            return 1;
        ccMgr->SetOSMEventId(osm_event_id);
        return ccMgr->Run();
    } catch (exception &e) {
        CongestionControlManager::printException(e, &p_osm->log);
        return 1;
    }
}


//============================================================================//
int updateCCMgr(osm_opensm_t *p_osm,
        osm_epi_event_id_t osm_event_id)
{
    try {
        if (!ccMgr)
            return 1;
        ccMgr->SetOSMEventId(osm_event_id);
        return ccMgr->UpdateFabricNodes();
    } catch (exception &e) {
        CongestionControlManager::printException(e, &p_osm->log);
        return 1;
    }
}


//============================================================================//
void setOSMEventIdCCMgr(osm_opensm_t *p_osm,
        osm_epi_event_id_t osm_event_id)
{
    try {
        if (!ccMgr)
            return;
        ccMgr->SetOSMEventId(osm_event_id);
    } catch (exception &e) {
        CongestionControlManager::printException(e, &p_osm->log);
    }
}


//============================================================================//
void destroyCCMgr(osm_opensm_t *p_osm)
{
    OSM_LOG(&p_osm->log, OSM_LOG_VERBOSE,
            "CC_MGR - Destroy Congestion Control Manager.\n");
    try {
        if (ccMgr)
            delete ccMgr;
    } catch (exception &e) {
        CongestionControlManager::printException(e, &p_osm->log);
    }
}
